.. _api:

API
===

**Sphinxit** is very young project and by now, Sphinxit API doesn't cover whole SphinxQL possibilities. 
Maybe you will not find some desired features and your notes, comments and pull requests are always welcome.

.. note::
    If you have found some silly mistakes, help me to make documentation better.

.. module:: sphinxit.search

.. autoclass:: SphinxConnector
    :members:

.. autoclass:: SphinxSearch
   :members:
   :inherited-members:

.. autoclass:: SphinxSnippets
   :members:
